@@ -222,6 +222,8 @@ class DroneHandler:
         repo_path = os.path.join(self._config.user["projects_home"], self._repo)
         yaml_path = os.path.join(repo_path, ".drone.yml")
         try:
-            return yaml.load_all(open(yaml_path, "r"), Loader=yaml.FullLoader)
+            return yaml.load_all(
+                open(yaml_path, "r", encoding="utf-8"), Loader=yaml.FullLoader
+            )
         except FileNotFoundError:
             return None
